@@ -45,12 +45,7 @@ SIZE = (1200, 900)
 def run():
     static_dir = (Path(__file__).parent / "static").resolve()
     eel.init(str(static_dir), allowed_extensions=[".html"])
-    eel.start(
-        "templates/index.html",
-        jinja_templates="templates",
-        size=SIZE,
-        block=True,
-    )
+    eel.start("templates/index.html", jinja_templates="templates", size=SIZE, block=True)
 
 
 @eel.expose
@@ -60,7 +55,7 @@ def autograder_run():
         return
     if GRADING_RESULTS:
         return GRADING_RESULTS
-    # Temporary value to signall that we started grading
+    # Temporary value to signal that we started grading
     GRADING_RESULTS = AUTOGRADER_RUN_IN_PROGRESS
 
     root_dir = skip_inner_dirs(Path(HOMEWORK_ROOT_DIR.name))
@@ -224,9 +219,7 @@ def extract_homeworks():
     global HOMEWORK_ROOT_DIR
 
     spawn_tkinter_window().title("Choose files to open")
-    chosen_paths = filedialog.askopenfilenames(
-        filetypes=[("Archive with student submissions", "*.zip"), ("Student Submissions", "*")]
-    )
+    chosen_paths = filedialog.askopenfilenames(filetypes=[("Student Submissions", "*")])
     if not chosen_paths:
         return {"error": "No path was chosen"}
     non_existent_paths = [f"'{p}'" for p in chosen_paths if not os.path.isfile(p)]
