@@ -1,7 +1,16 @@
 $(document).ready(async function () {
+    $(".loading-text").show();
     let results = await eel.autograder_run()();
+    $(".loading-text").hide();
     console.log(results);
     let output = "";
+    output += `<thead>
+        <tr>
+            <th>Testcases</th>
+            <th>Grade</th>
+        </tr>
+    </thead>`;
+
     for (let file of results.submissions) {
         output += `<tr>
                         <td>${file.submission} </td>
@@ -11,4 +20,3 @@ $(document).ready(async function () {
     $(".table-content").html(output);
 });
 
-
